ItemBuilder<T> typedef
ItemBuilder<T> =
Widget Function(BuildContext context, T item, int index)
A builder function that builds a widget for an item in the list.
The context is the build context.
The item is the item to build the widget for.
The index is the index of the item in the list.
Implementation
typedef ItemBuilder<T> = Widget Function(
BuildContext context, T item, int index);