LMChatAttachmentViewDataBuilder class

LMChatAttachmentViewDataBuilder is a builder class that helps in building the LMChatAttachmentViewData object.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

answerId(int? answerId) → void
attachmentBytes(Uint8List? attachmentBytes) → void
attachmentFile(File? attachmentFile) → void
build() LMChatAttachmentViewData
build method is used to create a new instance of LMChatAttachmentViewData with the provided values.
createdAt(int? createdAt) → void
dimensions(dynamic dimensions) → void
fileUrl(String? fileUrl) → void
height(dynamic height) → void
id(int? id) → void
index(int? index) → void
locationLat(dynamic locationLat) → void
locationLong(dynamic locationLong) → void
locationName(dynamic locationName) → void
meta(dynamic meta) → void
name(String? name) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
thumbnailBytes(Uint8List? thumbnailBytes) → void
thumbnailFile(File? thumbnailFile) → void
thumbnailUrl(String? thumbnailUrl) → void
toString() String
A string representation of this object.
inherited
type(String? type) → void
url(String? url) → void
width(dynamic width) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited