LMChatCustomPopupMenuStyle class

A class representing the style properties for a custom popup menu.

Constructors

LMChatCustomPopupMenuStyle({Color? backgroundColor, LMChatTextStyle? textStyle, LMChatIconStyle? iconStyle, Color? menuBoxForegroundColor, double? menuBoxHeight, double? menuBoxWidth, EdgeInsets? menuBoxPadding, EdgeInsets? menuBoxMargin, BoxDecoration? menuBoxDecoration, TextStyle? menuTextStyle})
Creates a new instance of LMChatCustomPopupMenuStyle.

Properties

backgroundColor Color?
The background color of the popup menu.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iconStyle LMChatIconStyle?
Icon style for the popup menu.
getter/setter pair
The decoration of the menu box.
getter/setter pair
The foreground color of the menu box.
getter/setter pair
The height of the menu box.
getter/setter pair
The margin of the menu box.
getter/setter pair
The padding of the menu box.
getter/setter pair
The width of the menu box.
getter/setter pair
Text style for the popup menu.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle LMChatTextStyle?
Text style for the popup menu.
getter/setter pair

Methods

copyWith({Color? backgroundColor, LMChatTextStyle? textStyle, LMChatIconStyle? iconStyle, Color? menuBoxForegroundColor, double? menuBoxHeight, double? menuBoxWidth, EdgeInsets? menuBoxPadding, EdgeInsets? menuBoxMargin, BoxDecoration? menuBoxDecoration, TextStyle? menuTextStyle}) LMChatCustomPopupMenuStyle
Creates a copy of this LMChatCustomPopupMenuStyle but with the given fields replaced with the new values. If the new values are null, the old values are used.
merge(LMChatCustomPopupMenuStyle? other) LMChatCustomPopupMenuStyle
Merges this LMChatCustomPopupMenuStyle with another LMChatCustomPopupMenuStyle.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited