LMChatDocumentThumbnailBuilder typedef

LMChatDocumentThumbnailBuilder = Widget Function(BuildContext context, LMChatAttachmentViewData attachment, LMChatDocumentThumbnail oldWidget)

The document thumbnail widget builder function for the chat screen. This function is called to build the document thumbnail widget for the chat screen. The LMChatDocumentThumbnailBuilder function takes three parameters:

Implementation

typedef LMChatDocumentThumbnailBuilder = Widget Function(
  BuildContext context,
  LMChatAttachmentViewData attachment,
  LMChatDocumentThumbnail oldWidget,
);