LMChatIconStyle class

Constructors

LMChatIconStyle({Color? color, double? size, double? boxSize, double? boxBorder, Color? boxBorderColor, double? boxBorderRadius, EdgeInsets? boxPadding, EdgeInsets? margin, Color? backgroundColor, BoxFit? fit})
const
LMChatIconStyle.basic()
factory

Properties

backgroundColor Color?
color of the box, or background color of icon
final
boxBorder double?
weight of the border around the box
final
boxBorderColor Color?
weight of the border around the box
final
boxBorderRadius double?
radius of the box around the icon
final
boxPadding EdgeInsets?
padding around icon with respect to the box
final
boxSize double?
square size of the box surrounding the icon
final
color Color?
color of the icon, not applicable on LMChatIconType.png
final
fit BoxFit?
fit inside the box for icon
final
hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsets?
margin around the box
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
square size of the icon
final

Methods

copyWith({Color? color, double? size, double? boxSize, double? boxBorder, double? boxBorderRadius, Color? boxBorderColor, EdgeInsets? boxPadding, EdgeInsets? margin, Color? backgroundColor, BoxFit? fit}) LMChatIconStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited