LMChatPopUpMenuStyle class

Constructors

LMChatPopUpMenuStyle({Color? backgroundColor, LMChatIcon? icon, LMChatIcon? activeIcon, Color? activeBackgroundColor, Color? activeColor, Color? inActiveColor, double? width, double? height, Border? border, Color? borderColor, double? borderWidth})
const

Properties

activeBackgroundColor Color?
Background color when the item is active
final
activeColor Color?
Color of the active item
final
activeIcon LMChatIcon?
Active icon for the pop-up menu
final
backgroundColor Color?
Background color of the pop-up menu
final
border Border?
Border for the pop-up menu
final
borderColor Color?
Color of the border
final
borderWidth double?
Width of the border
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Height of the pop-up menu
final
icon LMChatIcon?
Icon for the pop-up menu
final
inActiveColor Color?
Color of the inactive item
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
Width of the pop-up menu
final

Methods

copyWith({Color? backgroundColor, LMChatIcon? icon, LMChatIcon? activeIcon, Color? activeBackgroundColor, Color? activeColor, Color? inActiveColor, double? width, double? height}) LMChatPopUpMenuStyle
Creates a copy of the pop-up menu style with optional modifications
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited