LMChatProfilePictureBuilder typedef

LMChatProfilePictureBuilder = Widget? Function(BuildContext context, LMChatProfilePicture? profilePicture)

The profile picture builder function for the chat screen. This function is called to build the profile picture for the chat screen. The LMChatProfilePictureBuilder function takes two parameters:

Implementation

typedef LMChatProfilePictureBuilder = Widget? Function(
  BuildContext context,
  LMChatProfilePicture? profilePicture,
);