LMChatReactionKeyboardStyle class

Constructors

LMChatReactionKeyboardStyle({Color? buttonIconColor, Color? backgroundColor, Color? searchViewBackgroundColor, Color? dialogBackgroundColor, Color? indicatorColor, int? columns, double? emojiSizeMax, EdgeInsets? gridPadding, int? recentsLimit, Widget? noRecents, Widget? loadingIndicator})

Properties

backgroundColor Color?
The background color of the emoji keyboard.
final
buttonIconColor Color?
The color of the button icons in the keyboard.
final
columns int?
The number of columns in the emoji grid.
final
dialogBackgroundColor Color?
The background color of the dialog.
final
emojiSizeMax double?
The maximum size of the emojis.
final
gridPadding EdgeInsets?
The padding for the emoji grid.
final
hashCode int
The hash code for this object.
no setterinherited
indicatorColor Color?
The color of the indicator.
final
loadingIndicator Widget?
The widget displayed as a loading indicator.
final
noRecents Widget?
The widget displayed when there are no recent emojis.
final
recentsLimit int?
The limit for recent emojis.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchViewBackgroundColor Color?
The background color of the search view.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

basic() LMChatReactionKeyboardStyle
Creates a basic style configuration for the emoji keyboard.