LMChatTextFieldStyle class

Constructors

LMChatTextFieldStyle({InputDecoration? inputDecoration, TextStyle? textStyle, Color? tagColor, Color? suggestionsBoxColor, double? suggestionsBoxElevation, BorderRadius? suggestionsBoxBorderRadius, BoxConstraints? suggestionsBoxConstraints, EdgeInsets? suggestionsBoxPadding, Color? suggestionItemColor, EdgeInsets? suggestionItemPadding, LMChatTextStyle? suggestionItemTextStyle, LMChatProfilePictureStyle? suggestionItemAvatarStyle, Widget noItemsFoundBuilder(BuildContext)?, bool? showLoadingIndicator, Duration? debounceDuration, EdgeInsets? margin, int? maxLines, int? minLines})
const

Properties

debounceDuration Duration?
Duration of debounce on the text field
final
hashCode int
The hash code for this object.
no setterinherited
inputDecoration InputDecoration?
Decoration for the input field
final
margin EdgeInsets?
margin for the text field
final
maxLines int?
final
minLines int?
final
noItemsFoundBuilder Widget Function(BuildContext)?
Custom widget to show when no suggestions are found
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLoadingIndicator bool?
Whether to show a loading indicator while fetching suggestions
final
suggestionItemAvatarStyle LMChatProfilePictureStyle?
Style for the avatar in the suggestion item
final
suggestionItemColor Color?
Background color of the suggestion item
final
suggestionItemPadding EdgeInsets?
Padding for the suggestion item
final
suggestionItemTextStyle LMChatTextStyle?
Text style for the suggestion item
final
suggestionsBoxBorderRadius BorderRadius?
Border radius of the suggestions box
final
suggestionsBoxColor Color?
Background color of the suggestions box
final
suggestionsBoxConstraints BoxConstraints?
Constraints for the suggestions box
final
suggestionsBoxElevation double?
Elevation of the suggestions box
final
suggestionsBoxPadding EdgeInsets?
Padding for the suggestions box
final
tagColor Color?
Color of the tag in the input field
final
textStyle TextStyle?
Text style for the input field
final

Methods

copyWith({InputDecoration? inputDecoration, TextStyle? textStyle, Color? tagColor, Color? suggestionsBoxColor, double? suggestionsBoxElevation, BorderRadius? suggestionsBoxBorderRadius, BoxConstraints? suggestionsBoxConstraints, EdgeInsets? suggestionsBoxPadding, Color? suggestionItemColor, Duration? debounceDuration, EdgeInsets? suggestionItemPadding, LMChatTextStyle? suggestionItemTextStyle, LMChatProfilePictureStyle? suggestionItemAvatarStyle, EdgeInsets? margin, int? maxLines, int? minLines}) LMChatTextFieldStyle
Creates a copy of the text field style with optional modifications
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

basic({InputDecoration? inputDecoration, TextStyle? textStyle, Color? tagColor, Color? suggestionsBoxColor, double? suggestionsBoxElevation, BorderRadius? suggestionsBoxBorderRadius, BoxConstraints? suggestionsBoxConstraints, EdgeInsets? suggestionsBoxPadding, Color? suggestionItemColor, EdgeInsets? suggestionItemPadding, LMChatTextStyle? suggestionItemTextStyle, LMChatProfilePictureStyle? suggestionItemAvatarStyle}) LMChatTextFieldStyle
Creates a basic text field style with default values