LMChatBottomSheetStyle class
Constructors
-
LMChatBottomSheetStyle({LMChatTextStyle? titleStyle, Color? backgroundColor, BorderRadiusGeometry? borderRadius, double? height, double? elevation, EdgeInsets? padding, EdgeInsets? margin, List<
BoxShadow> ? boxShadow, Widget? dragBar, Color? dragBarColor}) -
const
Properties
- backgroundColor → Color?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
-
boxShadow
→ List<
BoxShadow> ? -
final
- dragBar → Widget?
-
final
- dragBarColor → Color?
-
final
- elevation → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- margin → EdgeInsets?
-
final
- padding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleStyle → LMChatTextStyle?
-
final
Methods
-
copyWith(
{Color? backgroundColor, BorderRadiusGeometry? borderRadius, double? height, double? elevation, EdgeInsets? padding, EdgeInsets? margin, List< BoxShadow> ? boxShadow, Widget? dragBar, Color? dragBarColor, LMChatTextStyle? titleStyle}) → LMChatBottomSheetStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited