ScreenSize class
Class to initialize the screen size
- Annotations
-
- @Deprecated('This class is deprecated and will be removed in future versions')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- blockSizeHorizontal ↔ double
-
Block size for horizontal layout
getter/setter pair
- blockSizeVertical ↔ double
-
Block size for vertical layout
getter/setter pair
- height ↔ double
-
Height of the screen
getter/setter pair
- pixelRatio ↔ double
-
Pixel ratio of the screen
getter/setter pair
- safeBlockHorizontal ↔ double
-
Safe block size for horizontal layout
getter/setter pair
- safeBlockVertical ↔ double
-
Safe block size for vertical layout
getter/setter pair
- textScale ↔ TextScaler
-
Text scaler for the screen
getter/setter pair
- width ↔ double
-
Width of the screen
getter/setter pair
Static Methods
-
init(
BuildContext context, {double? setWidth}) → dynamic - Initializes the screen size based on the provided context